﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win.UltraWinGrid;
using Infragistics.Win;

namespace GridTest
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
            this.ultraGrid1.InitializeLayout += new Infragistics.Win.UltraWinGrid.InitializeLayoutEventHandler(ultraGrid1_InitializeLayout);

            this.FillGrid();

            // ***
            this.ultraGrid1.DrawFilter = new SeparatorColumnDrawFilter();
        }

        void ultraGrid1_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            UltraGridLayout layout = e.Layout;
            UltraGridBand band = layout.Bands[0];
            UltraGridOverride ov = layout.Override;

            // create group 1
            var idxOfGrp1 = band.Groups.IndexOf("GROUP 1");
            if (idxOfGrp1 < 0)
                idxOfGrp1 = band.Groups.Add("GROUP 1").Index;

            // create the group for the separator
            var idxOfSepGrp = band.Groups.IndexOf("SEP GRP");
            if (idxOfSepGrp < 0)
                idxOfSepGrp = band.Groups.Add("SEP GRP").Index;

            // create group 2
            var idxOfGrp2 = band.Groups.IndexOf("GROUP 2");
            if (idxOfGrp2 < 0)
                idxOfGrp2 = band.Groups.Add("GROUP 2").Index;

            var grp1 = band.Groups[idxOfGrp1];
            var grp2 = band.Groups[idxOfGrp2];
            var sepGrp = band.Groups[idxOfSepGrp];

            foreach (var column in band.Columns)
            {
                if (column.Key == "COLUMN 0" || column.Key == "COLUMN 1" || column.Key == "COLUMN 2")
                    // ***
                    //column.Group = grp1;
                    column.RowLayoutColumnInfo.ParentGroup = grp1;
                if (column.Key == "COLUMN 3" || column.Key == "COLUMN 4" || column.Key == "COLUMN 5")
                    // ***
                    //column.Group = grp2;
                    column.RowLayoutColumnInfo.ParentGroup = grp2;
            }

            // add an unbound column 
            UltraGridColumn sepCol;
            int sepColIdx = band.Columns.IndexOf("SEPARATOR");
            if (sepColIdx < 0)
                sepCol = band.Columns.Add("SEPARATOR");
            else
                sepCol = band.Columns[sepColIdx];

            // ***
            band.RowLayoutStyle = RowLayoutStyle.GroupLayout;
            ov.BorderStyleRow = UIElementBorderStyle.None;
            ov.HeaderStyle = HeaderStyle.Standard;
            ov.BorderStyleHeader = UIElementBorderStyle.Solid;

            sepCol.CellAppearance.ThemedElementAlpha = Infragistics.Win.Alpha.Transparent;
            // ***
            //sepCol.Group = sepGrp;
            sepCol.RowLayoutColumnInfo.ParentGroup = sepGrp;

            sepGrp.Header.Appearance.BackColor = Color.Black;
            sepGrp.Header.Appearance.BackColor2 = Color.Black;
            sepGrp.Header.Appearance.BorderColor = Color.Black;
            sepGrp.Header.Appearance.BorderColor2 = Color.Black;
            sepGrp.Header.Appearance.BorderAlpha = Infragistics.Win.Alpha.Opaque;
            sepGrp.Header.Appearance.ThemedElementAlpha = Infragistics.Win.Alpha.Transparent;

            sepCol.CellActivation = Infragistics.Win.UltraWinGrid.Activation.Disabled;
            sepCol.CellAppearance.BackColor = Color.Black;
            sepCol.CellAppearance.BackColor2 = Color.Black;
            sepCol.CellAppearance.BorderColor = Color.Black;
            sepCol.CellAppearance.BorderColor2 = Color.Black;
            sepCol.CellAppearance.BorderAlpha = Infragistics.Win.Alpha.Opaque;
            sepCol.CellAppearance.ThemedElementAlpha = Infragistics.Win.Alpha.Transparent;

            sepCol.Header.Appearance.BackColor = Color.Black;
            sepCol.Header.Appearance.BackColor2 = Color.Black;
            sepCol.Header.Appearance.BorderColor = Color.Black;
            sepCol.Header.Appearance.BorderColor2 = Color.Black;
            sepCol.Header.Appearance.BorderColor3DBase = Color.Black;
            sepCol.Header.Appearance.BorderAlpha = Infragistics.Win.Alpha.Opaque;
            sepCol.Header.Appearance.ThemedElementAlpha = Infragistics.Win.Alpha.Transparent;

            sepCol.MinWidth = 7;
            sepCol.MaxWidth = 7;
            sepCol.Width = 7;

            sepCol.ExcludeFromColumnChooser = Infragistics.Win.UltraWinGrid.ExcludeFromColumnChooser.True;
            sepCol.LockedWidth = true;
        }

        private void FillGrid()
        {
            DataTable dt = new DataTable();
            dt.Columns.Add("COLUMN 0");
            dt.Columns.Add("COLUMN 1");
            dt.Columns.Add("COLUMN 2");
            dt.Columns.Add("COLUMN 3");
            dt.Columns.Add("COLUMN 4");
            dt.Columns.Add("COLUMN 5");

            for (int i = 0; i < 30; i++)
            {
                dt.Rows.Add("AAA", "BBB", "CCC", "DDD", "EEE", "FFF");
            }
            this.ultraGrid1.DataSource = dt;
        }

        private void buttonFill_Click(object sender, EventArgs e)
        {
            this.FillGrid();
        }
    }

    // ***
    internal class SeparatorColumnDrawFilter : IUIElementDrawFilter
    {
        #region IUIElementDrawFilter Members

        bool IUIElementDrawFilter.DrawElement(DrawPhase drawPhase, ref UIElementDrawParams drawParams)
        {
            drawParams.Graphics.FillRectangle(System.Drawing.Brushes.Black, drawParams.InvalidRect);
            return true;
        }

        DrawPhase IUIElementDrawFilter.GetPhasesToFilter(ref UIElementDrawParams drawParams)
        {            
            UltraGridColumn column = drawParams.Element.GetContext(typeof(UltraGridColumn)) as UltraGridColumn;
            if (column != null && column.Key == "SEPARATOR")
                return DrawPhase.BeforeDrawElement;

            UltraGridGroup group = drawParams.Element.GetContext(typeof(UltraGridGroup)) as UltraGridGroup;
            if (group != null && group.Key == "SEP GRP")
                return DrawPhase.BeforeDrawElement;

            GroupHeader groupHeader = drawParams.Element.GetContext(typeof(GroupHeader)) as GroupHeader;
            if (groupHeader != null && groupHeader.Group.Key == "SEP GRP")
                return DrawPhase.BeforeDrawElement;

            return DrawPhase.None;
        }

        #endregion
    }

}
